.. _callbacks:

================================
Developing with the callback API
================================

Scikit-learn offers a callback API to use built-in or custom callbacks with compatible
estimators. This section is intended for developers who wish to implement callbacks or
add callback support in estimators. For a general introduction to callbacks and how to
use them, see the :ref:`user guide <callbacks_user>`.

.. toctree::

   callback_support
   developing_callbacks
